cmd

package
v0.0.0-...-ebf9046 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: AGPL-3.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute is called by main.go

func RootCommand

func RootCommand(initResources bool) (*cobra.Command, error)

Initialize a root Cobra command.

Set initResources to false when generating documentation to avoid parsing configuration files and instantiating the API client, among other such external resources. This is to avoid depending on external state when doing doc generation.

Types

This section is empty.

Jump to