Documentation
¶
Index ¶
- func GenerateAndSignKey(client *api.Client, orgID string, resourceID string) (privPEM, pubKey, cert string, signData *api.SignSSHKeyData, err error)
- func RunExec(opts RunOpts) (int, error)
- func RunNative(opts RunOpts) (int, error)
- func SSHCmd() *cobra.Command
- func SignCmd() *cobra.Command
- type RunOpts
- type SSHPassthrough
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateAndSignKey ¶
func GenerateAndSignKey(client *api.Client, orgID string, resourceID string) (privPEM, pubKey, cert string, signData *api.SignSSHKeyData, err error)
GenerateAndSignKey generates an Ed25519 key pair and signs the public key via the API.
func RunExec ¶
RunExec runs an interactive SSH session by executing the system ssh binary (with a PTY when stdin is a terminal on Unix). Requires ssh to be installed. opts.PrivateKeyPEM and opts.Certificate must be set (JIT key + signed cert).
Types ¶
type SSHPassthrough ¶
func ParseOpenSSHPassThrough ¶
func ParseOpenSSHPassThrough(args []string) SSHPassthrough
ParseOpenSSHPassThrough walks pass-through args (e.g. args[1:] from "pangolin ssh <res> ...").
Click to show internal directories.
Click to hide internal directories.